##  Approach 1: Renaming the Label via Meta Model configuration
In this approach, you simply rename the label of the Transformation Item/Project Fact Sheet type and also the labels of the category fields by going to the Meta Model configuration.
  1. Go to Meta Model Configuration under Basic Settings and select Transformation Item/ Project Fact Sheet.
  2. Rename the label (Translation) of the Transformation Item/Project Fact Sheet type to Initiative from the right-side panel. The right-side panel appears when you click on the header section of the Fact Sheet. Also, make appropriate changes in the Help text field as it provides the right context for other users; for example, "Which Initiatives are currently changing the IT landscape?"
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274de3e17a4410148efbb71a0e7b781e_LowRes.jpg)
  3. Rename the label (Translation) of the category Plan to Idea and Building Block to Program.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27508cad7a4410149db9c68c0f53c898_LowRes.png)
  4. Click Show changes and then Apply
